==> zio-aws-fsx_2.12-5.17.124.3-sources.jar: zio/aws/fsx/model/BackupFailureDetails.scala <==
package zio.aws.fsx.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.fsx.model.primitives.ErrorMessage
import scala.jdk.CollectionConverters._
final case class BackupFailureDetails(message: Option[ErrorMessage] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.fsx.model.BackupFailureDetails = {
    import BackupFailureDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.fsx.model.BackupFailureDetails
      .builder()
      .optionallyWith(
        message.map(value => ErrorMessage.unwrap(value): java.lang.String)
      )(_.message)
      .build()
  }
  def asReadOnly: zio.aws.fsx.model.BackupFailureDetails.ReadOnly =
    zio.aws.fsx.model.BackupFailureDetails.wrap(buildAwsValue())
}
object BackupFailureDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.fsx.model.BackupFailureDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.fsx.model.BackupFailureDetails =
      zio.aws.fsx.model.BackupFailureDetails(message.map(value => value))
    def message: Option[ErrorMessage]
    def getMessage: ZIO[Any, AwsError, ErrorMessage] =
      AwsError.unwrapOptionField("message", message)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.fsx.model.BackupFailureDetails
  ) extends zio.aws.fsx.model.BackupFailureDetails.ReadOnly {
    override val message: Option[ErrorMessage] = scala
      .Option(impl.message())
      .map(value => zio.aws.fsx.model.primitives.ErrorMessage(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.fsx.model.BackupFailureDetails
  ): zio.aws.fsx.model.BackupFailureDetails.ReadOnly = new Wrapper(impl)
}

==> zio-aws-fsx_2.13-5.17.164.1-sources.jar: zio/aws/fsx/model/BackupFailureDetails.scala <==
package zio.aws.fsx.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.fsx.model.primitives.ErrorMessage
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class BackupFailureDetails(
    message: Optional[ErrorMessage] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.fsx.model.BackupFailureDetails = {
    import BackupFailureDetails.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.fsx.model.BackupFailureDetails
      .builder()
      .optionallyWith(
        message.map(value => ErrorMessage.unwrap(value): java.lang.String)
      )(_.message)
      .build()
  }
  def asReadOnly: zio.aws.fsx.model.BackupFailureDetails.ReadOnly =
    zio.aws.fsx.model.BackupFailureDetails.wrap(buildAwsValue())
}
object BackupFailureDetails {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.fsx.model.BackupFailureDetails
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.fsx.model.BackupFailureDetails =
      zio.aws.fsx.model.BackupFailureDetails(message.map(value => value))
    def message: Optional[ErrorMessage]
    def getMessage: ZIO[Any, AwsError, ErrorMessage] =
      AwsError.unwrapOptionField("message", message)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.fsx.model.BackupFailureDetails
  ) extends zio.aws.fsx.model.BackupFailureDetails.ReadOnly {
    override val message: Optional[ErrorMessage] = zio.aws.core.internal
      .optionalFromNullable(impl.message())
      .map(value => zio.aws.fsx.model.primitives.ErrorMessage(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.fsx.model.BackupFailureDetails
  ): zio.aws.fsx.model.BackupFailureDetails.ReadOnly = new Wrapper(impl)
}
